package com.abk;

import java.awt.image.BufferedImage;
import java.io.File;
import java.io.IOException;

import javax.imageio.ImageIO;

import com.drew.imaging.ImageMetadataReader;
import com.drew.imaging.ImageProcessingException;
import com.drew.metadata.Directory;
import com.drew.metadata.Metadata;
import com.drew.metadata.Tag;

import net.coobird.thumbnailator.Thumbnails;
import net.coobird.thumbnailator.filters.Flip;
import net.coobird.thumbnailator.filters.ImageFilter;
import net.coobird.thumbnailator.filters.Rotation;
import net.coobird.thumbnailator.resizers.configurations.Rendering;

public class ManageImageRotation {
	
	
	public void getImage(String name,String outputFileName) throws ImageProcessingException, IOException {

		Metadata metadata;
		try {
			File f = new File(name);
			metadata = ImageMetadataReader.readMetadata(f);
			System.out.println("Start");

			for (Directory directory : metadata.getDirectories()) {
				for (Tag tag : directory.getTags()) {
					if(tag.getTagName().equals("Orientation")){
						final Integer index = directory.getInteger(274);
						System.out.format("[%s] - %s = %s",
								directory.getName(), tag.getTagName(), index);
						BufferedImage image = getRotatedImage(f,index);
						File img = new File(outputFileName+".png");
						ImageIO.write(image,"png",img);
						
					}
				}
				if (directory.hasErrors()) {
					for (String error : directory.getErrors()) {
						System.err.format("ERROR: %s", error);
					}
				}
			}
		} catch (ImageProcessingException e) {
			System.out.println("Image processing exception while rotating image");
			throw e;
		} catch (IOException e) {
			System.out.println("IO exception while rotating image");
			throw e;
		}
	}
	
	private BufferedImage getRotatedImage(File f, Integer index) throws IOException {
		BufferedImage newImg =null;
		
		switch(index){
			case 1:
				//do nothing
				newImg = Thumbnails.of(f).scale(1).asBufferedImage();
				break;
			case 2:
				//Flip horizontal
				newImg = Thumbnails.of(f).scale(1).asBufferedImage();
				newImg = Flip.HORIZONTAL.apply(newImg);
				break;
			case 3:
				//rotate 180 clockwise
				newImg = Thumbnails.of(f).scale(1).rotate(180).asBufferedImage();
				break;
			case 4:
				//Flip vertical
				newImg = Thumbnails.of(f).scale(1).asBufferedImage();
				newImg = Flip.VERTICAL.apply(newImg);
				break;
			case 5:
				// rotate 90 counter cw and Flip horizontal
				newImg = Thumbnails.of(f).scale(1).rotate(-90).asBufferedImage();
				newImg = Flip.HORIZONTAL.apply(newImg);
				break;
			case 6:
				//rotate 90 clockwise
				newImg = Thumbnails.of(f).scale(1).rotate(90).asBufferedImage();
				break;
			case 7:
				//Rotate 90 clockwise and flip vertical
				newImg = Thumbnails.of(f).scale(1).rotate(90).asBufferedImage();
				newImg = Flip.VERTICAL.apply(newImg);
				break;
			case 8:
				//Rotate 0- counter cw
				newImg = Thumbnails.of(f).outputQuality(1.0).scale(1).rotate(-90).asBufferedImage();
				break;
			default:
				break;
		}
		return newImg;
	}
}
